@@ -1,3 +1,4 @@
+# coding=utf-8
 #
 # Copyright (C) 2010-2012 Platform Computing
 #
@@ -234,7 +235,7 @@ class HTMLRendering(Rendering):
 
         # body
         tmp += '\t\t<div id="entity"><ul>\n'
-        if len(entities) == 0:
+        if not len(entities):
             tmp += '\t\t\t<li>No resources found</li>\n'
         for item in entities:
             tmp += '\t\t\t<li><a href="' + item.identifier + '">'
@@ -258,6 +259,7 @@ class HTMLRendering(Rendering):
         tmp += '\t\t<div id="breadcrumb"><a href="/">&raquo;</a> /</div>\n'
 
         # body
+        tmp += '\t\t<div id="entity">\n'
         for cat in categories:
             tmp += '\t\t<h2><a name="' + cat.scheme + '-' + cat.term + '">'
             tmp += repr(cat).upper() + ': ' + cat.term + '</a></h2>\n'
@@ -299,7 +301,7 @@ class HTMLRendering(Rendering):
                 tmp += '</td></tr>\n'
             tmp += '\t\t</table>\n'
 
-        tmp += '\t</body>\n</html>'
+        tmp += '\t\t</div>\n\t</body>\n</html>'
         return {'Content-Type': self.mime_type}, tmp
 
     def to_action(self, headers, body, extras):
@@ -321,7 +323,7 @@ class HTMLRendering(Rendering):
         if tmp in cats:
             for item in self.registry.get_categories(extras):
                 if tmp == item:
-                    del(tmp)
-                    return item
+                    del tmp
+                    return item, {}
         else:
             raise AttributeError('Action is not defined. Check the QI.')
